@@ -2,11 +2,12 @@ import uuid
 from os import getenv
 
 from boto3utils import s3
-from cirrus.lib.process_payload import ProcessPayload
-from cirrus.lib.logging import get_task_logger
+
+from cirrus.lib2.logging import get_task_logger
+from cirrus.lib2.process_payload import ProcessPayload
 
 # envvars
-PAYLOAD_BUCKET = getenv('CIRRUS_PAYLOAD_BUCKET')
+PAYLOAD_BUCKET = getenv("CIRRUS_PAYLOAD_BUCKET")
 
 
 def lambda_handler(event, context):
@@ -20,9 +21,7 @@ def lambda_handler(event, context):
         s3().upload_json(payload, url)
 
         logger.debug(f"Uploaded payload to {url}")
-        return {
-            'url': url
-        }
+        return {"url": url}
     except Exception as err:
         msg = f"pre-batch: failed pre processing batch job for ({err})"
         logger.error(msg, exc_info=True)
