@@ -2,4 +2,4 @@ from .base import BaseCFObject
 
 
 class Mapping(BaseCFObject):
-    top_level_key = 'Mappings'
+    top_level_key = "Mappings"
