@@ -2,4 +2,4 @@ from .base import BaseCFObject
 
 
 class Parameter(BaseCFObject):
-    top_level_key = 'Parameters'
+    top_level_key = "Parameters"
