@@ -2,4 +2,4 @@ from .base import BaseCFObject
 
 
 class Rule(BaseCFObject):
-    top_level_key = 'Rules'
+    top_level_key = "Rules"
